@@ -59,12 +59,12 @@
 //	Conversions from half to float are lossless; all half numbers
 //	are exactly representable as floats.
 //
-//	Conversions from float to half may not preserve the float's
-//	value exactly.  If a float is not representable as a half, the
-//	float value is rounded to the nearest representable half.  If
-//	a float value is exactly in the middle between the two closest
+//	Conversions from float to half may not preserve a float's value
+//	exactly.  If a float is not representable as a half, then the
+//	float value is rounded to the nearest representable half.  If a
+//	float value is exactly in the middle between the two closest
 //	representable half values, then the float value is rounded to
-//	the half with the greater magnitude.
+//	the closest half whose least significant bit is zero.
 //
 //	Overflows during float-to-half conversions cause arithmetic
 //	exceptions.  An overflow occurs when the float value to be
@@ -85,6 +85,7 @@
 #ifndef _HALF_H_
 #define _HALF_H_
 
+#include "halfExport.h"    // for definition of HALF_EXPORT
 #include <iostream>
 
 class half
@@ -196,8 +197,8 @@ class half
     // Access to the internal representation
     //--------------------------------------
 
-    unsigned short	bits () const;
-    void		setBits (unsigned short bits);
+    HALF_EXPORT unsigned short	bits () const;
+    HALF_EXPORT void		setBits (unsigned short bits);
 
 
   public:
@@ -210,51 +211,33 @@ class half
 
   private:
 
-    static short	convert (int i);
-    static float	overflow ();
+    HALF_EXPORT static short                  convert (int i);
+    HALF_EXPORT static float                  overflow ();
 
-    unsigned short	_h;
+    unsigned short                            _h;
 
-    //---------------------------------------------------
-    // Windows dynamic libraries don't like static
-    // member variables.
-    //---------------------------------------------------
-#ifndef OPENEXR_DLL
-    static const uif	        _toFloat[1 << 16];
-    static const unsigned short _eLut[1 << 9];
-#endif
+    HALF_EXPORT static const uif              _toFloat[1 << 16];
+    HALF_EXPORT static const unsigned short   _eLut[1 << 9];
 };
 
-#if defined(OPENEXR_DLL)
-    //--------------------------------------
-    // Lookup tables defined for Windows DLL
-    //--------------------------------------
-    #if defined(HALF_EXPORTS)
-        extern __declspec(dllexport) half::uif		_toFloat[1 << 16];
-        extern __declspec(dllexport) unsigned short	_eLut[1 << 9];
-    #else
-        extern __declspec(dllimport) half::uif		_toFloat[1 << 16];
-        extern __declspec(dllimport) unsigned short	_eLut[1 << 9];
-    #endif
-#endif
 
 
 //-----------
 // Stream I/O
 //-----------
 
-std::ostream &		operator << (std::ostream &os, half  h);
-std::istream &		operator >> (std::istream &is, half &h);
+HALF_EXPORT std::ostream &      operator << (std::ostream &os, half  h);
+HALF_EXPORT std::istream &      operator >> (std::istream &is, half &h);
 
 
 //----------
 // Debugging
 //----------
 
-void			printBits   (std::ostream &os, half  h);
-void			printBits   (std::ostream &os, float f);
-void			printBits   (char  c[19], half  h);
-void			printBits   (char  c[35], float f);
+HALF_EXPORT void        printBits   (std::ostream &os, half  h);
+HALF_EXPORT void        printBits   (std::ostream &os, float f);
+HALF_EXPORT void        printBits   (char  c[19], half  h);
+HALF_EXPORT void        printBits   (char  c[35], float f);
 
 
 //-------------------------------------------------------------------------
@@ -294,6 +277,10 @@ void			printBits   (char  c[35], float f);
 #define HALF_DIG	2		// Number of base 10 digits that
 					// can be represented without change
 
+#define HALF_DECIMAL_DIG	5	// Number of base-10 digits that are
+					// necessary to uniquely represent all
+					// distinct values
+
 #define HALF_RADIX	2		// Base of the exponent
 
 #define HALF_MIN_EXP	-13		// Minimum negative integer such that
@@ -476,7 +463,7 @@ half::half (float f)
 	// to do the float-to-half conversion.
 	//
 
-	register int e = (x.i >> 23) & 0x000001ff;
+	int e = (x.i >> 23) & 0x000001ff;
 
 	e = _eLut[e];
 
@@ -487,7 +474,7 @@ half::half (float f)
 	    // bits and combine it with the sign and exponent.
 	    //
 
-	    register int m = x.i & 0x007fffff;
+	    int m = x.i & 0x007fffff;
 	    _h = e + ((m + 0x00000fff + ((m >> 13) & 1)) >> 13);
 	}
 	else
@@ -771,6 +758,4 @@ half::setBits (unsigned short bits)
     _h = bits;
 }
 
-#undef HALF_EXPORT_CONST
-
 #endif
